/*
  license GPL v3 ...........

  description of this file:
  a page for viewing a user selected RSS feed ;

*/

import QtQuick 2.0
import QtQuick.XmlListModel 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem
import "./dateutils.js" as DateUtils

Page {
    id: page_feed

    property string rssModelUrl: ""
    property string rssTitle: ""
    property int rssIndex: 0
    property variant rssModel

    onRssIndexChanged: {
        rssListview.currentIndex = rssIndex
        rssListview.positionViewAtIndex(rssListview.currentIndex, ListView.Center)
    }

    function setFeed(model, index) {
        console.log("Input index: ", index)
        rssModel = model
        rssIndex = index
    }

    function reloadPageContent() {

    }

    tools: ToolbarItems {
        id: toolbar

        ToolbarButton {
            action: Action {
                text:  i18n.tr("Open site")
                iconSource: Qt.resolvedUrl("./icons_tmp/go-to.svg")
                onTriggered:
                {
                    console.log("Open site", rssListview.model.get(rssListview.currentIndex).link)
                    Qt.openUrlExternally(rssListview.model.get(rssListview.currentIndex).link)
                }
            }
        }
    }

    //////////////////////////////////////////////      a listview to show the RSS content
    ListView {
        id: rssListview
        width: parent.width
        anchors.bottom: parent.bottom
        anchors.bottomMargin: units.gu(2)
        anchors.top: parent.top
        anchors.topMargin: units.gu(2)
        snapMode: ListView.SnapOneItem
        cacheBuffer: 90
        boundsBehavior: Flickable.StopAtBounds
        orientation: ListView.Horizontal
        contentHeight: parent.width * count
        model: rssModel
        delegate: xmlDelegate
        highlightFollowsCurrentItem: true
        highlightRangeMode: ListView.StrictlyEnforceRange

        onCurrentIndexChanged: {
            // console.log("ListView onCurrentIndexChanged", currentIndex)
            rssTitle = rssListview.model.get(currentIndex).feed_name
        }
    }

    //////////////////////////////////////////////      delegate for ListView
    Component {
        id: xmlDelegate

        Flickable {
            id: scrollArea

            clip: true

            width: rssListview.width
            height: rssListview.height

            contentWidth: width
            contentHeight: innerAreaColumn.height

            Column {
                id: innerAreaColumn

                spacing: units.gu(2)
                width: parent.width

                Label {
                    id: label_time
                    text: DateUtils.formatRelativeTime(i18n, pubdate)
                    fontSize: "small"
                    anchors.horizontalCenter: parent.horizontalCenter
                    width: parent.width - units.gu(4)
                }

                Label {
                    fontSize: "large"
                    text: title
                    anchors.horizontalCenter: parent.horizontalCenter
                    width: parent.width - units.gu(4)
                    wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                }

                Label {
                    text: content
                    linkColor: UbuntuColors.orange // Temporary. Mb bad color, but better than dark blue.
                    anchors.horizontalCenter: parent.horizontalCenter
                    width: parent.width - units.gu(4)
                    wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                    clip: true
                }

                Label {
                    id: label_feedname
                    text: rssTitle
                    fontSize: "small"
                    anchors.horizontalCenter: parent.horizontalCenter
                    width: parent.width - units.gu(4)
                    wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                }
            }
        } // Flickable
    } // Component
}
